@@ -5,12 +5,12 @@ from typing import Union, List, Optional, Dict
 
 from rx.subjects import Subject
 from twisted.internet import reactor
-from twisted.internet.defer import Deferred, DeferredList, succeed, inlineCallbacks
+from twisted.internet.defer import Deferred, DeferredList, succeed
 from twisted.python.failure import Failure
-from txws import WebSocketFactory
 
+from txws import WebSocketFactory
 from vortex.DeferUtil import yesMainThread
-from vortex.PayloadEnvelope import VortexMsgList, Payload, PayloadEnvelope
+from vortex.PayloadEnvelope import VortexMsgList, PayloadEnvelope
 from vortex.PayloadIO import PayloadIO
 from vortex.VortexABC import VortexABC
 from vortex.VortexClientHttp import VortexClientHttp
@@ -18,7 +18,8 @@ from vortex.VortexClientTcp import VortexClientTcp
 from vortex.VortexServer import VortexServer
 from vortex.VortexServerHttpResource import VortexServerHttpResource
 from vortex.VortexServerTcp import VortexTcpServerFactory
-from vortex.VortexServerWebsocket import VortexWebsocketServerFactory
+from vortex.VortexServerWebsocket import VortexWebsocketServerFactory, \
+    VortexWebSocketUpgradeResource, VortexWrappedWebSocketFactory
 
 logger = logging.getLogger(__name__)
 
@@ -127,6 +128,28 @@ class VortexFactory:
         vortexWebsocketServerFactory = VortexWebsocketServerFactory(vortexServer)
         reactor.listenTCP(port, WebSocketFactory(vortexWebsocketServerFactory))
 
+    @classmethod
+    def createHttpWebsocketServer(cls, name: str, rootResource) -> None:
+        """ Create Server
+
+        Create a vortex server, VortexServer clients connect to this vortex serer via HTTP(S)
+
+        VortexServer clients will connect and provide their names. This allows the factory to
+        abstract away the vortex UUIDs from their names.
+
+        :param name: The name of the local vortex.
+        :param port: The tcp port to listen on
+        :return: None
+        """
+
+        vortexServer = VortexServer(name)
+        cls.__vortexServersByName[name].append(vortexServer)
+        vortexWebsocketServerFactory = VortexWebsocketServerFactory(vortexServer)
+        websocketFactory = VortexWrappedWebSocketFactory(vortexWebsocketServerFactory)
+
+        websocketResource = VortexWebSocketUpgradeResource(websocketFactory)
+        rootResource.putChild(b"vortexws", websocketResource)
+
     @classmethod
     def createTcpServer(cls, name: str, port: int) -> None:
         """ Create Server
@@ -215,6 +238,16 @@ class VortexFactory:
 
         return remoteUuids
 
+    @classmethod
+    def getRemoteVortexName(cls) -> List[str]:
+        remoteNames = set()
+
+        for vortex in cls._allVortexes():
+            for remoteVortexInfo in vortex.remoteVortexInfo:
+                remoteNames.add(remoteVortexInfo.name)
+
+        return list(remoteNames)
+
     @classmethod
     def sendVortexMsg(cls,
                       vortexMsgs: Union[VortexMsgList, bytes],
@@ -270,7 +303,7 @@ class VortexFactory:
 
         vortexMsgs = [vortexMsgs] if isinstance(vortexMsgs, bytes) else vortexMsgs
 
-        def send(payloadEnvelope:PayloadEnvelope):
+        def send(payloadEnvelope: PayloadEnvelope):
             try:
                 PayloadIO().process(
                     payloadEnvelope=payloadEnvelope,
