@@ -7,54 +7,25 @@
  * Support : support@synerty.com
 """
 import logging
-from datetime import datetime
-from struct import pack
 from urllib.parse import urlparse, parse_qs
 
-import six
-import txws
-from twisted.internet import task
 from twisted.internet.defer import inlineCallbacks
 from twisted.internet.protocol import Protocol, connectionDone, Factory
+from twisted.protocols.policies import WrappingFactory
+from twisted.web import resource
+from twisted.web.server import NOT_DONE_YET
 
+from txws import WebSocketProtocol
 from vortex.DeferUtil import vortexLogFailure
 from vortex.PayloadEnvelope import PayloadEnvelope
 from vortex.VortexServerConnection import VortexServerConnection
-from .Payload import Payload
-from .VortexConnectionABC import VortexConnectionABC
-from .VortexServer import VortexServer, HEART_BEAT_PERIOD, HEART_BEAT_TIMEOUT
+from .VortexServer import VortexServer
 
 logger = logging.getLogger(name=__name__)
 
 
-def make_hybi07_frame(buf, opcode=0x1):
-    """
-    Make a HyBi-07 frame.
-
-    This function always creates unmasked frames, and attempts to use the
-    smallest possible lengths.
-    """
-
-    if len(buf) > 0xffff:
-        length = six.b("\x7f%s") % pack(">Q", len(buf))
-    elif len(buf) > 0x7d:
-        length = six.b("\x7e%s") % pack(">H", len(buf))
-    else:
-        length = six.b(chr(len(buf)))
-
-    if isinstance(buf, six.text_type):
-        buf = buf.encode('utf-8')
-
-    # Always make a normal packet.
-    header = chr(0x80 | opcode)
-    return six.b(header) + length + buf
-
-
-txws.make_hybi07_frame = make_hybi07_frame
-
-
 class VortexWebsocketServerProtocol(Protocol):
-    def __init__(self, vortex: VortexServer, addr) -> None:
+    def __init__(self, vortex: VortexServer, addr, httpSession=None) -> None:
         self._vortex = vortex
         self._addr = addr
 
@@ -62,7 +33,14 @@ class VortexWebsocketServerProtocol(Protocol):
 
         self._remoteVortexUuid = None
         self._remoteVortexName = None
-        self._httpSession = None
+        self._httpSession = httpSession
+
+        def httpSessionExpiredCallback():
+            self._httpSession = None
+            self.transport.loseConnection()
+
+        if self._httpSession:
+            self._httpSession.notifyOnExpire(httpSessionExpiredCallback)
 
         # Most messages don't need a buffer, but websockets can split messages
         # around the 128kb mark
@@ -73,14 +51,17 @@ class VortexWebsocketServerProtocol(Protocol):
 
         params = parse_qs(urlparse(self.transport.location).query)
 
+        if 'vortexUuid' not in params or 'vortexName' not in params:
+            raise Exception("This isn't a vortex capable websocket. Check the URL")
+
         self._remoteVortexUuid = params['vortexUuid'][0]
         self._remoteVortexName = params['vortexName'][0]
         self._conn = VortexServerConnection(self._vortex,
-                                               self._remoteVortexUuid,
-                                               self._remoteVortexName,
-                                               self._httpSession,
-                                               self.transport,
-                                               self._addr)
+                                            self._remoteVortexUuid,
+                                            self._remoteVortexName,
+                                            self._httpSession,
+                                            self.transport,
+                                            self._addr)
 
         # Send a heart beat down the new connection, tell it who we are.
         connectPayloadFilt = {}
@@ -98,6 +79,9 @@ class VortexWebsocketServerProtocol(Protocol):
         if self._vortex.isShutdown():
             return None
 
+        if self._httpSession:
+            self._httpSession.touch()
+
         if data == b'.':
             self._conn.beatReceived()
             return
@@ -109,8 +93,6 @@ class VortexWebsocketServerProtocol(Protocol):
             d.addErrback(vortexLogFailure, logger, consumeError=True)
             self._receiveBuffer = b''
 
-
-
     def connectionLost(self, reason=connectionDone):
         if self._conn:
             self._conn.transportClosed()
@@ -125,14 +107,52 @@ class VortexWebsocketServerProtocol(Protocol):
             payload=payloadEnvelope)
 
 
-
 class VortexWebsocketServerFactory(Factory):
     protocol = None
 
     def __init__(self, vortexServer: VortexServer) -> None:
         self._vortexServer = vortexServer
 
-    def buildProtocol(self, addr):
-        p = VortexWebsocketServerProtocol(self._vortexServer, addr)
+    def buildProtocol(self, addr, httpSession=None):
+        p = VortexWebsocketServerProtocol(self._vortexServer, addr, httpSession)
         p.factory = self
         return p
+
+
+class VortexWrappedWebSocketFactory(WrappingFactory):
+    """
+    Factory which wraps another factory to provide WebSockets transports for
+    all of its protocols.
+    """
+
+    protocol = WebSocketProtocol
+
+    def buildProtocol(self, addr, httpSession):
+        return self.protocol(self, self.wrappedFactory.buildProtocol(addr, httpSession))
+
+class VortexWebSocketUpgradeResource(resource.Resource):
+    """ Vortex Websocket Upgrade Resource
+
+    If this resource is hit, it will attempt to upgrade the connection to a websocket.
+
+    """
+    isLeaf = 1
+
+    def __init__(self, websocketFactory):
+        """ Constructor
+
+        @:param websocketFactory: A factory that will build a WebsocketProtocol (above)
+        """
+        resource.Resource.__init__(self)
+        self._websocketFactory = websocketFactory
+
+    def render(self, request):
+        httpSession = request.getSession()
+
+        websocketProtocol = self._websocketFactory \
+            .buildProtocol(request.client.host, httpSession)
+        websocketProtocol.makeConnection(request.channel.transport)
+        websocketProtocol.initFromRequest(request)
+        request.channel.upgradeToWebsocket(websocketProtocol)
+
+        return NOT_DONE_YET
